@@ -6,11 +6,6 @@
 __author__ = 'Dennis Ploeger <develop@dieploegers.de>'
 
 import sys
-if sys.version_info[0]==2:
-	from StringIO import StringIO
-elif sys.version_info[0]>=3:
-	from io import StringIO
-
 import base64
 import re
 import datetime
@@ -28,12 +23,19 @@ from xml.dom import Node
 
 from xml.dom.minidom import parseString, getDOMImplementation
 
+if sys.version_info[0] == 2:
+    from StringIO import StringIO
+elif sys.version_info[0] >= 3:
+    from io import StringIO
+
+
 def u(instring):
-    if sys.version_info[0]==2:
+    if sys.version_info[0] == 2:
         return PORTABLE_STRING(instring, 'utf-8')
     else:
         return PORTABLE_STRING(instring)
 
+
 def is_binary(test_string):
     """Return true if the given filename is binary.
     @attention: based on http://bytes
@@ -45,15 +47,16 @@ def is_binary(test_string):
         CHUNKSIZE = 1024
         while 1:
             chunk = fin.read(CHUNKSIZE)
-            if '\0' in chunk: # found null byte
+            if '\0' in chunk:  # found null byte
                 return True
             if len(chunk) < CHUNKSIZE:
-                break # done
+                break  # done
     finally:
         fin.close()
 
     return False
 
+
 class XMLRPCServiceDescriptor(ServiceDescriptor):
     """Generate XRDL (based on
         http://code.google.com/p/xrdl/source/browse/documentation/xrdl.xsd)"""
@@ -217,7 +220,8 @@ class XMLRPCServiceDescriptor(ServiceDescriptor):
 
         resp_doc.documentElement.appendChild(methods_el)
 
-        return resp_doc.toxml(encoding = encoding)
+        return resp_doc.toxml(encoding=encoding)
+
 
 class XMLRPCRequestHandler(BaseRequestHandler):
 
@@ -270,7 +274,7 @@ class XMLRPCRequestHandler(BaseRequestHandler):
                     raise ClientFault(
                         'Unexpected Node type %d while parsing '
                         'a struct member name' %
-                            name_node.firstChild.nodeType
+                        name_node.firstChild.nodeType
                     )
 
                 key = name_node.firstChild.data.strip()
@@ -297,7 +301,7 @@ class XMLRPCRequestHandler(BaseRequestHandler):
 
             return return_list
 
-    def parse_request(self,req,sinfo,encoding):
+    def parse_request(self, req, sinfo, encoding):
 
         req_dict = {'args': {}}
 
@@ -339,6 +343,7 @@ class XMLRPCRequestHandler(BaseRequestHandler):
 
         return req_dict
 
+
 class XMLRPCResponseHandler(BaseResponseHandler):
 
     _content_type = 'text/xml'
@@ -478,7 +483,7 @@ class XMLRPCResponseHandler(BaseResponseHandler):
 
         return value_el
 
-    def build_response(self,res_dict,sinfo,encoding):
+    def build_response(self, res_dict, sinfo, encoding):
         self.datetime_re = re.compile('\d{8}T\d{2}:\d{2}:\d{2}')
 
         value = res_dict['result']
@@ -497,19 +502,22 @@ class XMLRPCResponseHandler(BaseResponseHandler):
 
         resp_doc.documentElement.appendChild(params_el)
 
-        return resp_doc.toxml(encoding = encoding)
+        return resp_doc.toxml(encoding=encoding)
+
 
 class XMLRPCFaultHandler(BaseFaultHandler):
     _content_type = 'text/xml'
     _stringify_res_dict = False
 
-    def build_fault_response(self,service_exc,sinfo,methodname,encoding,reflection):
+    def build_fault_response(self, service_exc, sinfo, methodname, encoding, reflection):
         if service_exc.detail:
             detail = service_exc.detail
         else:
             detail = traceback.format_exc()
+        if service_exc.hint:
+            detail += "\n" + service_exc.hint
 
-        detail = detail.replace('\r\n','\n')
+        detail = detail.replace('\r\n', '\n')
 
         impl = getDOMImplementation()
 
@@ -572,19 +580,20 @@ class XMLRPCFaultHandler(BaseFaultHandler):
 
         resp_doc.documentElement.appendChild(fault_el)
 
-        return resp_doc.toxml(encoding = encoding)
+        return resp_doc.toxml(encoding=encoding)
+
 
 @expose
 class XMLRPCInterface(BaseInterface):
 
-    def __init__(self,sinfo,**kw):
+    def __init__(self, sinfo, **kw):
         def_kw = {
-        'service_descriptor': XMLRPCServiceDescriptor,
-        'request_handler': XMLRPCRequestHandler,
-        'response_handler': XMLRPCResponseHandler,
-        'fault_handler': XMLRPCFaultHandler}
+            'service_descriptor': XMLRPCServiceDescriptor,
+            'request_handler': XMLRPCRequestHandler,
+            'response_handler': XMLRPCResponseHandler,
+            'fault_handler': XMLRPCFaultHandler}
         def_kw.update(kw)
-        BaseInterface.__init__(self,sinfo,**def_kw)
+        BaseInterface.__init__(self, sinfo, **def_kw)
 
     @staticmethod
     def _interface_name():
@@ -592,7 +601,7 @@ class XMLRPCInterface(BaseInterface):
 
     @staticmethod
     def _accept_basetype(typ):
-        return pytype_support.count(typ)>0
+        return pytype_support.count(typ) > 0
 
     @staticmethod
     def _accept_list():
@@ -600,4 +609,4 @@ class XMLRPCInterface(BaseInterface):
 
     @staticmethod
     def _accept_dict():
-        return True
\ No newline at end of file
+        return True
